@@ -220,6 +220,7 @@ class RuleEngine:
         self.__event_listeners = set()
         self.__last_events = []
         self.__last_handled_events = []
+        self.openhab_uri = openhab_uri
         self.python_rule_directory = python_rule_directory
         logging.info("connecting " + openhab_uri)
         ItemRegistry.new_singleton(openhab_uri, user, pwd)
@@ -387,5 +388,5 @@ class RuleEngine:
                 rules.add(rule)
         return sorted(list(rules))
 
-#RuleEngine.start_singleton("http://192.168.1.27:8080", "C:\\workspace\\test", sys.argv[1], sys.argv[2])
-#sleep(10000)
\ No newline at end of file
+RuleEngine.start_singleton("http://192.2.1.11:8080", "C:\\temp\\test", sys.argv[1], sys.argv[2])
+sleep(10000)
\ No newline at end of file
